"""{{ feature_name }} feature module.

This feature provides {{ feature_description | default(feature_name + ' functionality') }}.
"""

from {{ feature_name }}.config import {{ feature_name | capitalize }}FeatureConfig

__all__ = ["{{ feature_name | capitalize }}FeatureConfig"]
