# Deploy Directory

This directory contains deployment configurations for your project.

Use `paxx deploy add` to add a deployment configuration:

```bash
paxx deploy add linux-server
```

Then, follow instructions in the deployment's `README.md` file to proceed further.
