# Git
.git
.gitignore

# Python
__pycache__
*.py[cod]
*$py.class
*.so
.Python
*.egg-info
*.egg
.eggs

# Virtual environments
.venv
venv
ENV
env

# IDE
.idea
.vscode
*.swp
*.swo
*~

# Testing
.pytest_cache
.coverage
htmlcov
.tox
.nox

# Type checking
.mypy_cache
.dmypy.json

# Environment files (secrets)
.env
.env.local
.env.*.local

# Database files (local dev)
*.db
*.sqlite
*.sqlite3

# Logs
*.log
logs

# OS
.DS_Store
Thumbs.db

# Docker
Dockerfile*
docker-compose*.yml
.dockerignore

# Documentation
*.md
docs

# Misc
tmp
temp
